Please see [https://docs.mlcommons.org/cm4mlops/scripts/Python-automation/get-python3](https://docs.mlcommons.org/cm4mlops/scripts/Python-automation/get-python3) for the documentation of this CM script.
